@@ -20,7 +20,8 @@
 #' - `conditional`, the names of the predictor variables from the *conditional*
 #'    model (as opposed to the zero-inflated part of a model)
 #' - `random`, the names of the random effects (grouping factors)
-#' - `zero_inflated`, the names of the predictor variables from the *zero-inflated* part of the model
+#' - `zero_inflated`, the names of the predictor variables from the
+#'   *zero-inflated* part of the model
 #' - `zero_inflated_random`, the names of the random effects (grouping factors)
 #' - `dispersion`, the name of the dispersion terms
 #' - `instruments`, the names of instrumental variables
@@ -73,9 +74,9 @@ find_terms.default <- function(x,
   resp <- find_response(x, verbose = FALSE)
 
   if (is_multivariate(f) || isTRUE(attributes(f)$two_stage)) {
-    l <- lapply(f, .get_variables_list, resp = resp)
+    l <- lapply(f, .get_variables_list, resp = resp, model = x)
   } else {
-    l <- .get_variables_list(f, resp)
+    l <- .get_variables_list(f, resp, model = x)
   }
 
   if (flatten) {
@@ -100,6 +101,27 @@ find_terms.default <- function(x,
 }
 
 
+#' @export
+find_terms.insight_formula <- function(x, flatten = FALSE, verbose = TRUE, ...) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  resp <- find_response(x, verbose = FALSE)
+
+  if (is_multivariate(x)) {
+    l <- lapply(x, .get_variables_list, resp = resp, model = NULL)
+  } else {
+    l <- .get_variables_list(x, resp, model = NULL)
+  }
+
+  if (flatten) {
+    unique(unlist(l, use.names = FALSE))
+  } else {
+    l
+  }
+}
+
 
 #' @export
 find_terms.aovlist <- function(x, flatten = FALSE, verbose = TRUE, ...) {
@@ -169,11 +191,10 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 }
 
 
-
 # helper -----------------------
 
 
-.get_variables_list <- function(f, resp = NULL) {
+.get_variables_list <- function(f, resp = NULL, model = NULL) {
   # exception for formula w/o response
   if (is.null(resp) || !is_empty_object(resp)) {
     f$response <- sub("(.*)::(.*)", "\\2", safe_deparse(f$conditional[[2L]]))
@@ -220,16 +241,21 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
     f$response <- original_response
   }
 
-  # remove "1" and "0" from variables in random effects
-
-  if (object_has_names(f, "random")) {
-    pos <- which(f$random %in% c("1", "0"))
-    if (length(pos)) f$random <- f$random[-pos]
+  # for brms-models, we need to remove "Intercept", which is a special notation
+  if (inherits(model, "brmsfit")) {
+    f <- lapply(f, function(i) {
+      compact_character(gsub("\\QIntercept\\E", "", i))
+    })
   }
 
-  if (object_has_names(f, "zero_inflated_random")) {
-    pos <- which(f$zero_inflated_random %in% c("1", "0"))
-    if (length(pos)) f$zero_inflated_random <- f$zero_inflated_random[-pos]
+  # remove "1" and "0" from variables in random effects
+
+  re_comp <- endsWith(names(f), "random")
+  if (any(re_comp)) {
+    for (i in names(f)[re_comp]) {
+      pos <- which(f[[i]] %in% c("1", "0"))
+      if (length(pos)) f[[i]] <- f[[i]][-pos]
+    }
   }
 
   # restore -1
