@@ -52,7 +52,7 @@ find_weights.brmsfit <- function(x, ...) {
   f <- find_formula(x, verbose = FALSE)
 
   if (is_multivariate(f)) {
-    resp <- unlist(lapply(f, function(i) safe_deparse(i$conditional[[2L]])))
+    resp <- unlist(lapply(f, function(i) safe_deparse(i$conditional[[2L]])), use.names = FALSE)
   } else {
     resp <- safe_deparse(f$conditional[[2L]])
   }
@@ -96,3 +96,24 @@ find_weights.merMod <- function(x, ...) {
     }
   )
 }
+
+
+#' @export
+find_weights.lme <- function(x, ...) {
+  w <- find_weights.default(x, ...)
+  # any weights? If so, get formula
+  if (!is.null(w)) {
+    # in lme(), weights are either an optional varFunc object or a one-sided
+    # formula. The formula is usally stored in "$modelStruct$varStruct"
+    w_formula <- .safe(stats::formula(x$modelStruct$varStruct))
+    if (!is.null(w_formula)) {
+      w <- all.vars(w_formula)
+    } else {
+      w <- NULL
+    }
+  }
+  w
+}
+
+#' @export
+find_weights.gls <- find_weights.lme
