@@ -1,19 +1,19 @@
 # Bayesian --------------------------------------------------------------
 # =======================================================================
 
-
 #' @rdname get_predicted
 #' @export
-get_predicted.stanreg <- function(x,
-                                  data = NULL,
-                                  predict = "expectation",
-                                  iterations = NULL,
-                                  ci = NULL,
-                                  ci_method = NULL,
-                                  include_random = "default",
-                                  include_smooth = TRUE,
-                                  verbose = TRUE,
-                                  ...) {
+get_predicted.stanreg <- function(
+    x,
+    data = NULL,
+    predict = "expectation",
+    iterations = NULL,
+    ci = NULL,
+    ci_method = NULL,
+    include_random = "default",
+    include_smooth = TRUE,
+    verbose = TRUE,
+    ...) {
   check_if_installed("rstantools")
 
   if (is.null(ci_method)) {
@@ -51,7 +51,8 @@ get_predicted.stanreg <- function(x,
   # }
 
   # prepare arguments, avoid possible matching by multiple actual arguments
-  fun_args <- list(x,
+  fun_args <- list(
+    x,
     newdata = my_args$data,
     re.form = my_args$re.form,
     dpar = my_args$distributional_parameter,
@@ -82,7 +83,10 @@ get_predicted.stanreg <- function(x,
   model_family <- get_family(x)
   # exceptions
   is_wiener <- inherits(model_family, "brmsfamily") && model_family$family == "wiener"
-  is_rtchoice <- model_family$family == "custom" && model_family$name == "lnr"
+  is_rtchoice <- inherits(model_family, "brmsfamily") &&
+    model_family$family == "custom" &&
+    model_family$name == "lnr"
+  is_mixture <- inherits(model_family, "brmsfamily") && model_family$family == "mixture"
 
   # Special case for rwiener (get choice 1 as negative values)
   # Note that for mv models, x$family returns a list of families
@@ -100,8 +104,13 @@ get_predicted.stanreg <- function(x,
   }
 
   # Handle special cases
-  if (!my_args$predict %in% c("expectation", "response", "link") && inherits(model_family, "brmsfamily")) {
+  if (
+    !my_args$predict %in% c("expectation", "response", "link") &&
+      inherits(model_family, "brmsfamily")
+  ) {
     if (is_wiener) {
+      # Wiener (Drift Diffusion) Models --------------------
+      # ----------------------------------------------------
       # Separate RT from Choice and assemble into 3D matrix (as if it was a multivariate)
       response <- as.numeric(draws >= 0)
       draws <- abs(draws)
@@ -111,6 +120,8 @@ get_predicted.stanreg <- function(x,
         dimnames = list(NULL, NULL, c("rt", "response"))
       )
     } else if (is_rtchoice) {
+      # Reaction time and Choice Models --------------------
+      # ----------------------------------------------------
       # LogNormal Race models (cogmod package) return RT and Choice as odd and even columns
       response <- as.matrix(draws[, seq(2, ncol(draws), 2)])
       draws <- as.matrix(draws[, seq(1, ncol(draws), 2)])
@@ -119,6 +130,39 @@ get_predicted.stanreg <- function(x,
         dim = c(dim(draws), 2),
         dimnames = list(NULL, NULL, c("rt", "response"))
       )
+    } else if (is_mixture && identical(my_args$predict, "classification")) {
+      # Mixture (multi membership) Models --------------------
+      # ------------------------------------------------------
+      # confidence intervals?
+      if (!is.null(ci) && !is.na(ci)) {
+        probs <- c((1 - ci) / 2, (1 + ci) / 2)
+        fun_args$probs <- probs
+      }
+      # for mixture models, which predict the class membership, we stop
+      # here and just return the predicted class membership
+      mixture_output <- do.call(brms::pp_mixture, fun_args)
+      # pp_mixture() returns an array with predicted probability for class
+      # assignment for each observation. we here return the class definition
+      # with the highest probability per observation
+      predictions <- apply(mixture_output[, 1, ], 1, which.max)
+      # add confidence intervals
+      if (is.null(ci) || is.na(ci)) {
+        ci_data <- NULL
+      } else {
+        # pp_mixture returns an array with probs, SE and intervals.
+        # if requested, we extract the intervals here for the "ci_data"
+        # data.frame
+        res <- lapply(seq_len(nrow(mixture_output)), function(i) {
+          max_prob <- which.max(mixture_output[i, 1, ])
+          data.frame(
+            Probability = mixture_output[i, 1, max_prob],
+            CI_low = mixture_output[i, 3, max_prob],
+            CI_high = mixture_output[i, 4, max_prob]
+          )
+        })
+        ci_data <- do.call(rbind, res)
+      }
+      return(.get_predicted_out(predictions, my_args = my_args, ci_data = ci_data))
     }
   }
 
@@ -129,6 +173,7 @@ get_predicted.stanreg <- function(x,
     datagrid = my_args$data,
     is_wiener = is_wiener,
     is_rtchoice = is_rtchoice,
+    is_mixture = is_mixture,
     ...
   )
 
