@@ -4,19 +4,19 @@
 #' @description Collection of small helper functions. `trim_ws()` is an
 #' efficient function to trim leading and trailing whitespaces from character
 #' vectors or strings. `n_unique()` returns the number of unique values in a
-#' vector. `has_single_value()` is equivalent to `n_unique() == 1` but is faster.
-#' `safe_deparse()` is comparable to `deparse1()`, i.e. it can safely
-#' deparse very long expressions into a single string. `safe_deparse_symbol()`
-#' only deparses a substituted expressions when possible, which can be much faster
-#' than `deparse(substitute())` for those cases where `substitute()` returns no
-#' valid object name.
+#' vector. `has_single_value()` is equivalent to `n_unique() == 1` but is faster
+#' (note the different default for the `remove_na` argument). `safe_deparse()`
+#' is comparable to `deparse1()`, i.e. it can safely deparse very long
+#' expressions into a single string. `safe_deparse_symbol()` only deparses a
+#' substituted expressions when possible, which can be much faster than
+#' `deparse(substitute())` for those cases where `substitute()` returns no valid
+#' object name.
 #'
 #' @param x A (character) vector, or for some functions may also be a data frame.
 #' @param remove_na Logical, if missing values should be removed from the input.
 #' @param character_only Logical, if `TRUE` and `x` is a data frame or list,
 #' only processes character vectors.
 #' @param ... Currently not used.
-#' @param na.rm Deprecated. Use `remove_na` instead.
 #'
 #' @return
 #' - `n_unique()`: For a vector, `n_unique` always returns an integer value,
@@ -47,7 +47,7 @@ trim_ws <- function(x, ...) {
 
 #' @export
 trim_ws.default <- function(x, ...) {
-  gsub("^\\s+|\\s+$", "", x, perl = TRUE, useBytes = TRUE)
+  gsub("^\\s+|\\s+$", "", x, useBytes = TRUE)
 }
 
 #' @rdname trim_ws
@@ -78,7 +78,6 @@ trim_ws.list <- function(x, character_only = TRUE, ...) {
 }
 
 
-
 # n_unique ---------------------------------------
 
 #' @rdname trim_ws
@@ -89,41 +88,25 @@ n_unique <- function(x, ...) {
 
 #' @rdname trim_ws
 #' @export
-n_unique.default <- function(x, remove_na = TRUE, na.rm = TRUE, ...) {
+n_unique.default <- function(x, remove_na = TRUE, ...) {
   if (is.null(x)) {
     return(0)
   }
-  ## TODO:: remove deprecation warning later
-  if (!missing(na.rm)) {
-    format_warning("The `na.rm` argument is deprecated. Use `remove_na` instead.")
-    remove_na <- na.rm
-  }
   if (isTRUE(remove_na)) x <- x[!is.na(x)]
   length(unique(x))
 }
 
 #' @export
-n_unique.data.frame <- function(x, remove_na = TRUE, na.rm = TRUE, ...) {
-  ## TODO:: remove deprecation warning later
-  if (!missing(na.rm)) {
-    format_warning("The `na.rm` argument is deprecated. Use `remove_na` instead.")
-    remove_na <- na.rm
-  }
+n_unique.data.frame <- function(x, remove_na = TRUE, ...) {
   vapply(x, n_unique, remove_na = remove_na, FUN.VALUE = numeric(1L))
 }
 
 #' @export
-n_unique.list <- function(x, remove_na = TRUE, na.rm = TRUE, ...) {
-  ## TODO:: remove deprecation warning later
-  if (!missing(na.rm)) {
-    format_warning("The `na.rm` argument is deprecated. Use `remove_na` instead.")
-    remove_na <- na.rm
-  }
+n_unique.list <- function(x, remove_na = TRUE, ...) {
   lapply(x, n_unique, remove_na = remove_na)
 }
 
 
-
 # safe_deparse ---------------------------------------
 
 #' @rdname trim_ws
@@ -132,11 +115,10 @@ safe_deparse <- function(x, ...) {
   if (is.null(x)) {
     return(NULL)
   }
-  paste0(sapply(deparse(x, width.cutoff = 500), trim_ws, simplify = TRUE), collapse = " ")
+  paste(sapply(deparse(x, width.cutoff = 500), trim_ws, simplify = TRUE), collapse = " ")
 }
 
 
-
 # safe_substitute ---------------------------------------
 
 #' @rdname trim_ws
@@ -155,12 +137,7 @@ safe_deparse_symbol <- function(x) {
 
 #' @rdname trim_ws
 #' @export
-has_single_value <- function(x, remove_na = FALSE, na.rm = TRUE, ...) {
-  ## TODO:: remove deprecation warning later
-  if (!missing(na.rm)) {
-    format_warning("The `na.rm` argument is deprecated. Use `remove_na` instead.")
-    remove_na <- na.rm
-  }
+has_single_value <- function(x, remove_na = FALSE, ...) {
   if (remove_na) x <- x[!is.na(x)]
   !is.null(x) && length(x) > 0L && isTRUE(all(x == x[1]))
 }
