@@ -26,6 +26,11 @@ test_that("get_loglikelihood - lm", {
   x <- lm(log(mpg) ~ wt, data = mtcars)
   expect_equal(as.numeric(get_loglikelihood(x)), 19.42433, tolerance = 1e-3)
   expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -75.21614, tolerance = 1e-3)
+  expect_equal(
+    as.numeric(get_loglikelihood(x, check_response = TRUE)),
+    as.numeric(get_loglikelihood(x)) + as.numeric(get_loglikelihood_adjustment(x)),
+    tolerance = 1e-3
+  )
 
   set.seed(123)
   mtcars$wg <- abs(rnorm(nrow(mtcars), mean = 1))
@@ -36,11 +41,34 @@ test_that("get_loglikelihood - lm", {
   expect_equal(as.numeric(get_loglikelihood(x)), 18.4205, tolerance = 1e-3)
   expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -75.58669, tolerance = 1e-3)
 
-
   # sqrt-response
   x <- lm(sqrt(mpg) ~ wt, data = mtcars)
   expect_equal(as.numeric(get_loglikelihood(x)), -7.395031, tolerance = 1e-3)
   expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -76.89597, tolerance = 1e-3)
+
+  # power to x
+  x <- lm(mpg^3.5 ~ wt, weights = wg, data = mtcars)
+  expect_equal(as.numeric(get_loglikelihood(x)), -385.6256, tolerance = 1e-3)
+  expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -110.5192, tolerance = 1e-3)
+
+  # scale
+  x <- lm(mpg / 3.5 ~ wt, weights = wg, data = mtcars)
+  expect_equal(as.numeric(get_loglikelihood(x)), -41.94534, tolerance = 1e-3)
+  expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -82.03376, tolerance = 1e-3)
+
+  # scale, no weights
+  x <- lm(mpg / 3.5 ~ wt, data = mtcars)
+  expect_equal(as.numeric(get_loglikelihood(x)), -39.9263, tolerance = 1e-3)
+  expect_equal(as.numeric(get_loglikelihood(x, check_response = TRUE)), -80.01471, tolerance = 1e-3)
+})
+
+test_that("get_loglikelihood - not supported", {
+  # Box-Cox
+  m <- lm((mpg^0.7 - 1) / 0.7 ~ hp, data = mtcars)
+  expect_warning(get_loglikelihood(m, check_response = TRUE), regex = "Could not compute")
+  # Inverse
+  m <- lm(1 / mpg ~ hp, data = mtcars)
+  expect_warning(get_loglikelihood(m, check_response = TRUE), regex = "Could not compute")
 })
 
 test_that("get_loglikelihood - glm", {
@@ -62,6 +90,7 @@ test_that("get_loglikelihood - glm", {
 })
 
 test_that("get_loglikelihood - (g)lmer", {
+  skip_if_not_installed("curl")
   skip_if_offline()
   skip_if_not_installed("lme4")
   x <- lme4::lmer(Sepal.Length ~ Sepal.Width + (1 | Species), data = iris)
@@ -93,7 +122,7 @@ test_that("get_loglikelihood - (g)lmer", {
   ll2 <- stats::logLik(x, REML = FALSE)
   expect_equal(as.numeric(ll), as.numeric(ll2), tolerance = 1e-4, ignore_attr = TRUE)
 
-  skip_if_not_installed("httr")
+  skip_if_not_installed("httr2")
 
   model <- download_model("lmerMod_1")
   skip_if(is.null(model))
@@ -200,3 +229,16 @@ test_that("get_loglikelihood - Bernoulli with inversed levels", {
   expect_equal(logLik(ml_ones), get_loglikelihood(ml_ones), ignore_attr = TRUE)
   expect_equal(get_loglikelihood(ml_zero), get_loglikelihood(ml_ones), ignore_attr = TRUE)
 })
+
+test_that("get_loglikelihood - fails for negative values for some transformation", {
+  data(mtcars)
+  dafr <- data.frame(y = mtcars$mpg * -1, x = mtcars$hp)
+  m <- lm(y^2 ~ x, data = dafr)
+  expect_warning(get_loglikelihood(m, check_response = TRUE), regex = "Could not")
+  expect_equal(
+    get_loglikelihood(m, check_response = TRUE, verbose = FALSE),
+    get_loglikelihood(m, verbose = FALSE),
+    tolerance = 1e-4
+  )
+  expect_null(get_loglikelihood_adjustment(m))
+})
